@@ -1,10 +1,14 @@
 package App::Oozie::Date;
-$App::Oozie::Date::VERSION = '0.002';
+$App::Oozie::Date::VERSION = '0.003';
 use 5.010;
 use strict;
 use warnings;
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
+use App::Oozie::Constants qw(
+    DATE_PATTERN
+    SHORTCUT_METHODS
+);
 use Carp qw( croak );
 use DateTime;
 use DateTime::Format::Strptime;
@@ -12,16 +16,6 @@ use DateTime::Format::Duration;
 use Moo;
 use Types::Standard qw( Str );
 
-use constant DATE_PATTERN => '%Y-%m-%d';
-# Alternatively, we can think about using sub attributes to gather this
-# dynamically instead of being a hardcoded constant, but that can also be
-# a bit over engineering.
-use constant SHORTCUT_METHODS => qw(
-    today
-    tomorrow
-    yesterday
-);
-
 has strp => (
     is      => 'ro',
     default => sub {
@@ -182,7 +176,7 @@ App::Oozie::Date
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -225,12 +219,6 @@ App::Oozie::Date - Date related functions.
 
 =head3 timezone
 
-=head1 Constants
-
-=head2 DATE_PATTERN
-
-=head2 SHORTCUT_METHODS
-
 =head1 SEE ALSO
 
 L<App::Oozie>.
