@@ -1,14 +1,14 @@
 package App::Oozie::Deploy;
-$App::Oozie::Deploy::VERSION = '0.002';
+$App::Oozie::Deploy::VERSION = '0.003';
 use 5.010;
 use strict;
 use warnings;
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
-use constant {
-    FILE_FIND_FOLLOW_SKIP_IGNORE_DUPLICATES => 2,
-};
-
+use App::Oozie::Constants qw(
+    FILE_FIND_FOLLOW_SKIP_IGNORE_DUPLICATES
+    WEBHDFS_CREATE_CHUNK_SIZE
+);
 use Cwd 'abs_path';
 use Moo;
 use MooX::Options prefer_commandline => 0,
@@ -20,8 +20,6 @@ Deploys workflows to HDFS. Specifying names as final arguments will upload only
 USAGE
 ;
 
-use Data::Dumper;
-
 use App::Oozie::Deploy::Template;
 use App::Oozie::Deploy::Validate::Spec;
 use App::Oozie::Types::Common qw( IsDir IsFile );
@@ -57,8 +55,6 @@ use Types::Standard qw(
     Str
 );
 
-use constant WEBHDFS_CREATE_CHUNK_SIZE => 1024**1024 * 2;
-
 with qw(
     App::Oozie::Role::Log
     App::Oozie::Role::Fields::Common
@@ -113,8 +109,6 @@ option dump_xml_to_json => (
     doc     => 'Specify a directory to convert and dump XML files in the workflow as JSON. This implies a dryrun.',
 );
 
-sub _remove_n { my $s = shift; $s =~ s{\n+}{ }xmsg; $s }
-
 #------------------------------------------------------------------------------#
 
 has required_tt_files => (
@@ -1116,7 +1110,7 @@ App::Oozie::Deploy
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -1211,12 +1205,6 @@ App::Oozie::Deploy - The program to deploy Oozie workflows.
 
 =head3 ttlib_dynamic_base_dir_name
 
-=head1 Constants
-
-=head2 FILE_FIND_FOLLOW_SKIP_IGNORE_DUPLICATES
-
-=head2 WEBHDFS_CREATE_CHUNK_SIZE
-
 =head1 SEE ALSO
 
 L<App::Oozie>.
